Overview on extracted features
==============================

*tsfresh* calculates a comprehensive number of features. All feature calculators are contained in the

.. autosummary::
   :toctree: _generated
   :template: module_functions_template.rst

    tsfresh.feature_extraction.feature_calculators

submodule. 

The following, exhaustive list contains all features that are calculated in the current version of *tsfresh*:

.. include:: _generated/tsfresh.feature_extraction.feature_calculators.rst
